; sage_setup: distribution = sagemath-maxima

;(setf *prompt-prefix* "<prompt>")
;(setf *prompt-suffix* "</prompt>")
;(setf *general-display-prefix* "<sage-display>")

(setf *prompt-prefix* "<sage-display>")

